<?php

use Illuminate\Support\HtmlString;
use Illuminate\Support\Collection;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Request;

if ( !function_exists('current_query_to_array')) {
    /**
     * Retourne un tableau avec les paramètres de l'url courante
     * @return array Un tableau contenant les paramètres
     */
    function current_query_to_array()
    {
        parse_str(Request::getQueryString(), $array);

        return $array;
    }
}

if (! function_exists('current_query_to_string')) {
    /**
     * Retourne paramètres de l'url courante sans ses paramètres vides
     * @return string La requête courante
     */
    function current_query_to_string() : string
    {
        $queries = array_filter(current_query_to_array());
        return http_build_query($queries);
    }
}

if (! function_exists('current_route_belongs')) {
    /**
     * Vérifie si l'url courante appartient (enfant compris) à une route
     * @param string    La route à tester
     * @return string
     */
    function current_route_belongs($route_name) : string
    {
        $route = route($route_name, [], false);
        $uri = trim($route, '/');
        return Request::is($uri . '*');
    }
}

if (! function_exists('current_parent_route_belongs')) {
    /**
     * Vérifie si l'url courante appartient (enfant compris) à une route parent (segment -1)
     * @param string    La route à tester
     * @return string
     */
    function current_parent_route_belongs($route_name) : string
    {
        $route = route($route_name, [], false);
        $route = preg_replace('/\/([^\/]*\/?)$/', '', $route);
        $uri = trim($route, '/');

        return Request::is($uri . '*');
    }
}
